<?php

/**
 * FiddlemailInstall
 *
 * @author M. Burkard
 */
abstract class FiddlemailInstall {
	
	private static $dbversion = '1.1.0';
	
	public static function onPluginActivate() {
		$option_defaults = array(
			'fm_api_key' => '',
			'fm_api_key_score' => 0,
			'fm_filter' => 1,
			'fm_api_send_mail' => 0,
			'fm_api_block_score' => 75,
			'fm_use_spamhaus' => 75,
			'fm_use_uribl' => 75,
			'fm_comment_handling' => 1
		);
		
		foreach($option_defaults as $key => $default) {
			if(!get_option($key)) {
				update_option($key, $default);
			}
		}
		
		if(get_site_option('fm_db_version' ) != self::$dbversion) {
			self::onDatabaseUpdate();
		}
	}
	
	public static function onDatabaseCheck() {
		if(get_site_option('fm_db_version' ) != self::$dbversion) {
			self::onDatabaseUpdate();
		}
	}
	
	/**
	 * @global wpdb $wpdb
	 */
	public static function onDatabaseUpdate() {
		global $wpdb;
		
		$charset_collate = $wpdb->get_charset_collate();

		require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
		
		$sql = 'CREATE TABLE ' . $wpdb->prefix . Fiddlemail::$logtable . ' (
id bigint(20) NOT NULL AUTO_INCREMENT,
logtime datetime DEFAULT \'0000-00-00 00:00:00\' NOT NULL,
checked_mail varchar(200) DEFAULT \'\' NOT NULL,
check_context varchar(50) DEFAULT \'\' NOT NULL,
score smallint(3) DEFAULT \'0\' NOT NULL,
result varchar(25) DEFAULT \'\' NOT NULL,
PRIMARY KEY  (id)
) ' . $charset_collate . ';

CREATE TABLE ' . $wpdb->prefix . Fiddlemail::$wblisttable . ' (
domain varchar(100) DEFAULT \'\' NOT NULL,
type ENUM(\'w\', \'b\') DEFAULT \'w\' NOT NULL,
PRIMARY KEY (domain)
) ' . $charset_collate . ';';
		
		dbDelta( $sql );
		
		update_option('fm_db_version', self::$dbversion);
	}
	
	public static function onPluginDeactivate() {

	}
	
	public static function showSettingsLink($links, $file) {
		static $this_plugin;
		if (!$this_plugin) {
			$this_plugin = plugin_basename(__FILE__);
		}

		if ($file == $this_plugin) {
			$settings_link = '<a href="options-general.php?page=fiddlemail-settings">' . __('Settings', 'fiddlemail') . '</a>';
			array_unshift($links, $settings_link);
		}

		return $links;
	}
}
